@@ -58,23 +58,53 @@ impl Bitboard {
 
     /// Returns the bitboard containing all squares of the given rank.
     #[inline]
-    pub fn rank(rank: Rank) -> Bitboard {
+    pub fn from_rank(rank: Rank) -> Bitboard {
         Bitboard(RANKS[usize::from(rank)])
     }
 
+    #[deprecated(since = "0.20.4", note = "Renamed to Bitboard::from_rank()")]
+    #[inline]
+    pub fn rank(rank: Rank) -> Bitboard {
+        Bitboard::from_rank(rank)
+    }
+
     /// Returns the bitboard containing all squares of the given file.
     #[inline]
-    pub fn file(file: File) -> Bitboard {
+    pub fn from_file(file: File) -> Bitboard {
         Bitboard(FILES[usize::from(file)])
     }
 
+    #[deprecated(since = "0.20.4", note = "Renamed to Bitboard::from_file()")]
+    #[inline]
+    pub fn file(file: File) -> Bitboard {
+        Bitboard::from_file(file)
+    }
+
     /// Like `rank()`, but from the point of view of `color`.
+    #[deprecated(since = "0.20.4", note = "Use color.relative_rank()")]
     #[inline]
     pub fn relative_rank(color: Color, rank: Rank) -> Bitboard {
-        Bitboard::rank(color.fold_wb(rank, rank.flip_vertical()))
+        Bitboard::from_rank(color.fold_wb(rank, rank.flip_vertical()))
     }
 
     /// Shift using `<<` for `White` and `>>` for `Black`.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use shakmaty::{Bitboard, Color};
+    ///
+    /// let bitboard = Bitboard(0x1e22_2212_0e0a_1222);
+    /// assert_eq!(bitboard.relative_shift(Color::Black, 8), Bitboard(0x001e_2222_120e_0a12));
+    /// // . . . . . . . .
+    /// // . 1 1 1 1 . . .
+    /// // . 1 . . . 1 . .
+    /// // . 1 . . . 1 . .
+    /// // . 1 . . 1 . . .
+    /// // . 1 1 1 . . . .
+    /// // . 1 . 1 . . . .
+    /// // . 1 . . 1 . . .
+    /// ```
     #[must_use]
     #[inline]
     pub fn relative_shift(self, color: Color, shift: u32) -> Bitboard {
@@ -84,12 +114,30 @@ impl Bitboard {
         }
     }
 
+    /// Tests if `self` is non-empty.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use shakmaty::Bitboard;
+    ///
+    /// assert!(Bitboard::BACKRANKS.any());
+    /// ```
     #[must_use]
     #[inline]
     pub fn any(self) -> bool {
         self.0 != 0
     }
 
+    /// Tests if `self` is empty.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use shakmaty::Bitboard;
+    ///
+    /// assert!(Bitboard::EMPTY.is_empty());
+    /// ```
     #[inline]
     pub fn is_empty(self) -> bool {
         self.0 == 0
@@ -97,7 +145,7 @@ impl Bitboard {
 
     #[inline]
     pub fn contains(self, sq: Square) -> bool {
-        !(self & Bitboard::from_square(sq)).is_empty()
+        (self & Bitboard::from_square(sq)).any()
     }
 
     #[inline]
@@ -171,11 +219,29 @@ impl Bitboard {
         (self & other).is_empty()
     }
 
+    /// Tests if `self` is a subset of `other`.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use shakmaty::Bitboard;
+    ///
+    /// assert!(Bitboard::DARK_SQUARES.is_subset(Bitboard::FULL));
+    /// ```
     #[inline]
     pub fn is_subset<T: Into<Bitboard>>(self, other: T) -> bool {
         (self & !other.into()).is_empty()
     }
 
+    /// Tests if `self` is a superset of `other`.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use shakmaty::Bitboard;
+    ///
+    /// assert!(Bitboard::FULL.is_superset(Bitboard::LIGHT_SQUARES));
+    /// ```
     #[inline]
     pub fn is_superset<T: Into<Bitboard>>(self, other: T) -> bool {
         other.into().is_subset(self)
@@ -436,26 +502,192 @@ impl Bitboard {
     }
 
     /// An empty bitboard.
+    ///
+    /// ```
+    /// # use shakmaty::Bitboard;
+    /// #
+    /// # let bitboard = Bitboard::EMPTY;
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// ```
     pub const EMPTY: Bitboard = Bitboard(0);
 
     /// A bitboard containing all squares.
+    ///
+    /// ```
+    /// # use shakmaty::Bitboard;
+    /// #
+    /// # let bitboard = Bitboard::FULL;
+    /// // 1 1 1 1 1 1 1 1
+    /// // 1 1 1 1 1 1 1 1
+    /// // 1 1 1 1 1 1 1 1
+    /// // 1 1 1 1 1 1 1 1
+    /// // 1 1 1 1 1 1 1 1
+    /// // 1 1 1 1 1 1 1 1
+    /// // 1 1 1 1 1 1 1 1
+    /// // 1 1 1 1 1 1 1 1
+    /// ```
     pub const FULL: Bitboard = Bitboard(!0);
 
     /// All dark squares.
+    ///
+    /// ```
+    /// # use shakmaty::Bitboard;
+    /// #
+    /// # let bitboard = Bitboard::DARK_SQUARES;
+    /// // . 1 . 1 . 1 . 1
+    /// // 1 . 1 . 1 . 1 .
+    /// // . 1 . 1 . 1 . 1
+    /// // 1 . 1 . 1 . 1 .
+    /// // . 1 . 1 . 1 . 1
+    /// // 1 . 1 . 1 . 1 .
+    /// // . 1 . 1 . 1 . 1
+    /// // 1 . 1 . 1 . 1 .
+    /// ```
     pub const DARK_SQUARES: Bitboard = Bitboard(0xaa55_aa55_aa55_aa55);
 
     /// All light squares.
+    ///
+    /// ```
+    /// # use shakmaty::Bitboard;
+    /// #
+    /// # let bitboard = Bitboard::LIGHT_SQUARES;
+    /// // 1 . 1 . 1 . 1 .
+    /// // . 1 . 1 . 1 . 1
+    /// // 1 . 1 . 1 . 1 .
+    /// // . 1 . 1 . 1 . 1
+    /// // 1 . 1 . 1 . 1 .
+    /// // . 1 . 1 . 1 . 1
+    /// // 1 . 1 . 1 . 1 .
+    /// // . 1 . 1 . 1 . 1
+    /// ```
     pub const LIGHT_SQUARES: Bitboard = Bitboard(0x55aa_55aa_55aa_55aa);
 
     /// The four corner squares.
+    ///
+    /// ```
+    /// # use shakmaty::Bitboard;
+    /// #
+    /// # let bitboard = Bitboard::CORNERS;
+    /// // 1 . . . . . . 1
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // 1 . . . . . . 1
+    /// ```
     pub const CORNERS: Bitboard = Bitboard(0x8100_0000_0000_0081);
 
     /// The backranks.
+    ///
+    /// ```
+    /// # use shakmaty::Bitboard;
+    /// #
+    /// # let bitboard = Bitboard::BACKRANKS;
+    /// // 1 1 1 1 1 1 1 1
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // 1 1 1 1 1 1 1 1
+    /// ```
     pub const BACKRANKS: Bitboard = Bitboard(0xff00_0000_0000_00ff);
 
     /// The four center squares.
+    ///
+    /// ```
+    /// # use shakmaty::Bitboard;
+    /// #
+    /// # let bitboard = Bitboard::CENTER;
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . 1 1 . . .
+    /// // . . . 1 1 . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// ```
     pub const CENTER: Bitboard = Bitboard(0x0000_0018_1800_0000);
 
+    /// The northern half of the board.
+    ///
+    /// ```
+    /// # use shakmaty::Bitboard;
+    /// #
+    /// # let bitboard = Bitboard::NORTH;
+    /// // 1 1 1 1 1 1 1 1
+    /// // 1 1 1 1 1 1 1 1
+    /// // 1 1 1 1 1 1 1 1
+    /// // 1 1 1 1 1 1 1 1
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// ```
+    pub const NORTH: Bitboard = Bitboard(0xffff_ffff_0000_0000);
+
+    /// The southern half of the board.
+    ///
+    /// ```
+    /// # use shakmaty::Bitboard;
+    /// #
+    /// # let bitboard = Bitboard::SOUTH;
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // . . . . . . . .
+    /// // 1 1 1 1 1 1 1 1
+    /// // 1 1 1 1 1 1 1 1
+    /// // 1 1 1 1 1 1 1 1
+    /// // 1 1 1 1 1 1 1 1
+    /// ```
+    pub const SOUTH: Bitboard = Bitboard(0x0000_0000_ffff_ffff);
+
+    /// The western half of the board.
+    ///
+    /// ```
+    /// # use shakmaty::Bitboard;
+    /// #
+    /// # let bitboard = Bitboard::WEST;
+    /// // 1 1 1 1 . . . .
+    /// // 1 1 1 1 . . . .
+    /// // 1 1 1 1 . . . .
+    /// // 1 1 1 1 . . . .
+    /// // 1 1 1 1 . . . .
+    /// // 1 1 1 1 . . . .
+    /// // 1 1 1 1 . . . .
+    /// // 1 1 1 1 . . . .
+    /// ```
+    pub const WEST: Bitboard = Bitboard(0x0f0f_0f0f_0f0f_0f0f);
+
+    /// The eastern half of the board.
+    ///
+    /// ```
+    /// # use shakmaty::Bitboard;
+    /// #
+    /// # let bitboard = Bitboard::EAST;
+    /// // . . . . 1 1 1 1
+    /// // . . . . 1 1 1 1
+    /// // . . . . 1 1 1 1
+    /// // . . . . 1 1 1 1
+    /// // . . . . 1 1 1 1
+    /// // . . . . 1 1 1 1
+    /// // . . . . 1 1 1 1
+    /// // . . . . 1 1 1 1
+    /// ```
+    pub const EAST: Bitboard = Bitboard(0xf0f0_f0f0_f0f0_f0f0);
+
     #[deprecated(since = "0.20.1", note = "Renamed to Bitboard::FULL for consistency")]
     pub const ALL: Bitboard = Bitboard::FULL;
 }
@@ -493,6 +725,36 @@ static FILES: [u64; 8] = {
     masks
 };
 
+#[derive(Copy, Clone)]
+pub(crate) enum Direction {
+    NorthWest,
+    NorthEast,
+    SouthWest,
+    SouthEast,
+}
+
+impl Direction {
+    #[inline(always)]
+    pub fn offset(self) -> i32 {
+        match self {
+            Direction::NorthWest => 7,
+            Direction::SouthWest => -9,
+            Direction::NorthEast => 9,
+            Direction::SouthEast => -7,
+        }
+    }
+
+    #[inline(always)]
+    pub fn translate(self, bitboard: Bitboard) -> Bitboard {
+        Bitboard(match self {
+            Direction::NorthWest => (bitboard.0 & !FILES[0]) << 7,
+            Direction::SouthWest => (bitboard.0 & !FILES[0]) >> 9,
+            Direction::NorthEast => (bitboard.0 & !FILES[7]) << 9,
+            Direction::SouthEast => (bitboard.0 & !FILES[7]) >> 7,
+        })
+    }
+}
+
 impl fmt::Debug for Bitboard {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         for rank in (0..8).map(Rank::new).rev() {
@@ -541,14 +803,14 @@ impl From<Square> for Bitboard {
 impl From<Rank> for Bitboard {
     #[inline]
     fn from(rank: Rank) -> Bitboard {
-        Bitboard::rank(rank)
+        Bitboard::from_rank(rank)
     }
 }
 
 impl From<File> for Bitboard {
     #[inline]
     fn from(file: File) -> Bitboard {
-        Bitboard::file(file)
+        Bitboard::from_file(file)
     }
 }
 
@@ -799,7 +1061,7 @@ mod tests {
 
     #[test]
     fn test_rank() {
-        assert_eq!(Bitboard::rank(Rank::Fourth), Bitboard(0xff00_0000));
+        assert_eq!(Bitboard::from_rank(Rank::Fourth), Bitboard(0xff00_0000));
     }
 
     #[test]
