@@ -84,6 +84,14 @@ impl Color {
         self.fold_wb(Rank::First, Rank::Eighth)
     }
 
+    #[inline]
+    pub fn relative_rank(self, rank: Rank) -> Rank {
+        match self {
+            Color::White => rank,
+            Color::Black => rank.flip_vertical(),
+        }
+    }
+
     pub fn char(self) -> char {
         self.fold_wb('w', 'b')
     }
@@ -212,6 +220,7 @@ impl<T> ByColor<T> {
         mem::swap(&mut self.white, &mut self.black);
     }
 
+    #[must_use]
     pub fn into_flipped(self) -> ByColor<T> {
         ByColor {
             white: self.black,
@@ -306,6 +315,7 @@ impl<T: PartialOrd> ByColor<T> {
         }
     }
 
+    #[must_use]
     pub fn into_normalized(mut self) -> ByColor<T> {
         self.normalize();
         self
