@@ -92,6 +92,8 @@ impl FenOpts {
 
     /// Decide if castling rights should be displayed in Shredder format,
     /// e.g. `HAha` instead of `KQkq`.
+    ///
+    /// Defaults to `false`.
     pub fn shredder(&mut self, shredder: bool) -> &mut FenOpts {
         self.shredder = shredder;
         self
@@ -99,6 +101,8 @@ impl FenOpts {
 
     /// Decide if Crazyhouse pockets and remaining check counters should use
     /// Scid-style, e.g. `/q` instead of `[q]` and `+0+0` instead of `3+3`.
+    ///
+    /// Defaults to `false`.
     pub fn scid(&mut self, scid: bool) -> &mut FenOpts {
         self.scid = scid;
         self
@@ -110,8 +114,7 @@ impl FenOpts {
         for color in Color::ALL {
             let king = board.king_of(color);
 
-            let candidates =
-                board.by_piece(color.rook()) & Bitboard::relative_rank(color, Rank::First);
+            let candidates = board.by_piece(color.rook()) & color.backrank();
 
             for rook in (candidates & castling_rights).into_iter().rev() {
                 if !self.shredder
@@ -455,11 +458,14 @@ impl Fen {
         P::from_setup(self, mode)
     }
 
-    /// Parses a FEN.
+    /// Parses a FEN or EPD.
+    ///
+    /// FENs consist of parts separated by spaces. This parser also accepts
+    /// parts separated by underscores. Missing parts are filled with defaults.
     ///
     /// # Errors
     ///
-    /// Returns [`ParseFenError`] if the input is not a valid FEN.
+    /// Returns [`ParseFenError`] if any part is syntactically invalid.
     ///
     /// # Example
     ///
@@ -471,7 +477,7 @@ impl Fen {
     /// # Ok::<_, Box<dyn std::error::Error>>(())
     /// ```
     pub fn from_ascii(fen: &[u8]) -> Result<Fen, ParseFenError> {
-        let mut parts = fen.split(|ch| *ch == b' ');
+        let mut parts = fen.split(|ch| *ch == b' ' || *ch == b'_');
         let mut result = Fen::empty();
 
         let board_part = parts.next().expect("splits have at least one part");
@@ -521,8 +527,7 @@ impl Fen {
                 for &ch in castling_part {
                     let color = Color::from_white(ch < b'a'); // uppercase
 
-                    let candidates = Bitboard::relative_rank(color, Rank::First)
-                        & result.board.by_piece(color.rook());
+                    let candidates = result.board.by_piece(color.rook()) & color.backrank();
 
                     let flag = match ch | 32 {
                         b'k' => candidates.last(),
