@@ -14,15 +14,19 @@
 // You should have received a copy of the GNU General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-use std::cmp::{Ord, Ordering, PartialOrd};
-use std::fmt;
-use std::error::Error;
-use std::iter::FromIterator;
-use std::str::FromStr;
-use std::ops::{Add, AddAssign, Sub, SubAssign};
+use std::{
+    cmp::{Ord, Ordering, PartialOrd},
+    error::Error,
+    fmt,
+    iter::FromIterator,
+    ops::{Add, AddAssign, Sub, SubAssign},
+    str::FromStr,
+};
 
-use crate::color::{Color, ByColor};
-use crate::types::{Piece, Role};
+use crate::{
+    color::{ByColor, Color},
+    types::{Piece, Role},
+};
 
 /// Error when parsing an invalid material key.
 #[derive(Clone, Debug)]
@@ -75,21 +79,21 @@ impl MaterialSide {
     }
 
     pub fn is_empty(&self) -> bool {
-        self.pawns == 0 &&
-        self.knights == 0 &&
-        self.bishops == 0 &&
-        self.rooks == 0 &&
-        self.queens == 0 &&
-        self.kings == 0
+        self.pawns == 0
+            && self.knights == 0
+            && self.bishops == 0
+            && self.rooks == 0
+            && self.queens == 0
+            && self.kings == 0
     }
 
     pub fn count(&self) -> usize {
-        usize::from(self.pawns) +
-        usize::from(self.knights) +
-        usize::from(self.bishops) +
-        usize::from(self.rooks) +
-        usize::from(self.queens) +
-        usize::from(self.kings)
+        usize::from(self.pawns)
+            + usize::from(self.knights)
+            + usize::from(self.bishops)
+            + usize::from(self.rooks)
+            + usize::from(self.queens)
+            + usize::from(self.kings)
     }
 
     pub fn has_pawns(&self) -> bool {
@@ -101,21 +105,23 @@ impl MaterialSide {
             return Err(ParseMaterialError);
         }
 
-        let mut result = MaterialSide::new();
-
-        for &ch in s {
-            let role = Role::from_char(char::from(ch)).ok_or(ParseMaterialError)?;
-            *result.by_role_mut(role) += 1;
-        }
-
-        Ok(result)
+        s.iter()
+            .copied()
+            .map(|ch| Role::from_char(char::from(ch)).ok_or(ParseMaterialError))
+            .collect()
     }
 }
 
 impl fmt::Display for MaterialSide {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        for role in IntoIterator::into_iter(Role::ALL).rev() {
-            f.write_str(&role.char().to_uppercase().to_string().repeat(usize::from(self.by_role(role))))?;
+        for role in Role::ALL.into_iter().rev() {
+            f.write_str(
+                &role
+                    .char()
+                    .to_uppercase()
+                    .to_string()
+                    .repeat(usize::from(self.by_role(role))),
+            )?;
         }
         Ok(())
     }
@@ -152,7 +158,8 @@ impl FromIterator<Role> for MaterialSide {
 
 impl Ord for MaterialSide {
     fn cmp(&self, other: &MaterialSide) -> Ordering {
-        self.count().cmp(&other.count())
+        self.count()
+            .cmp(&other.count())
             .then(self.kings.cmp(&other.kings))
             .then(self.queens.cmp(&other.queens))
             .then(self.rooks.cmp(&other.rooks))
@@ -263,7 +270,7 @@ impl Material {
     }
 
     pub fn is_empty(&self) -> bool {
-        self.white.is_empty() && self.black.is_empty()
+        self.all(MaterialSide::is_empty)
     }
 
     pub fn count(&self) -> usize {
@@ -271,34 +278,71 @@ impl Material {
     }
 
     pub fn has_pawns(&self) -> bool {
-        self.white.has_pawns() || self.black.has_pawns()
+        self.any(MaterialSide::has_pawns)
     }
 
+    /// Parse material from notation like `KPPvKR`.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`ParseMaterialError`] if there are any unrecognized
+    /// characters, not exactly one `v` to separate white pieces from black
+    /// pieces, or more than 64 pieces.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use shakmaty::Material;
+    ///
+    /// let material = Material::from_ascii(b"KPPvKR")?;
+    /// assert_eq!(material.white.kings, 1);
+    /// assert_eq!(material.white.pawns, 2);
+    /// assert_eq!(material.black.kings, 1);
+    /// assert_eq!(material.black.rooks, 1);
+    /// # Ok::<_, Box<dyn std::error::Error>>(())
+    /// ```
     pub fn from_ascii(s: &[u8]) -> Result<Material, ParseMaterialError> {
+        if s.len() > 64 + 1 {
+            return Err(ParseMaterialError);
+        }
+
         let mut parts = s.splitn(2, |ch| *ch == b'v');
 
         Ok(Material {
-            white: match parts.next() {
-                Some(w) => MaterialSide::from_ascii(w)?,
-                None => MaterialSide::new(),
-            },
-            black: match parts.next() {
-                Some(b) => MaterialSide::from_ascii(b)?,
-                None => MaterialSide::new(),
-            },
+            white: MaterialSide::from_ascii(parts.next().expect("split non-empty"))?,
+            black: MaterialSide::from_ascii(parts.next().ok_or(ParseMaterialError)?)?,
         })
     }
 
+    /// Parse material from notation like `KPPkr`, where white pieces are
+    /// uppercase characters and black pieces are lowercase characters.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`ParseMaterialError`] if there are any unrecognized
+    /// characters, or more than 64 pieces.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use shakmaty::Material;
+    ///
+    /// let material = Material::from_ascii_fen(b"KPPkr")?;
+    /// assert_eq!(material.white.kings, 1);
+    /// assert_eq!(material.white.pawns, 2);
+    /// assert_eq!(material.black.kings, 1);
+    /// assert_eq!(material.black.rooks, 1);
+    /// # Ok::<_, Box<dyn std::error::Error>>(())
+    /// ```
     pub fn from_ascii_fen(s: &[u8]) -> Result<Material, ParseMaterialError> {
         if s.len() > 64 {
             return Err(ParseMaterialError);
         }
 
-        let mut material = Material::new();
-        for &ch in s {
-            *material.by_piece_mut(Piece::from_char(char::from(ch)).ok_or(ParseMaterialError)?) += 1;
-        }
-        Ok(material)
+        s.iter()
+            .copied()
+            .map(|ch| Piece::from_char(char::from(ch)).ok_or(ParseMaterialError))
+            .collect()
     }
 
     pub fn fen(&self) -> String {
@@ -325,7 +369,7 @@ impl fmt::Display for Material {
 
 impl Extend<Piece> for Material {
     fn extend<T: IntoIterator<Item = Piece>>(&mut self, iter: T) {
-        for piece in iter.into_iter().take(64usize.saturating_sub(self.count())) {
+        for piece in iter.into_iter().take(64_usize.saturating_sub(self.count())) {
             *self.by_piece_mut(piece) += 1;
         }
     }
